# from examples.langchain_example.basic import basic, load_and_split, rag


# from examples.openai.chat_completion import chat_completion

# from examples.openai import images_generate
# from examples.openai.function_calling import function_calling
# from examples.anthropic_example.completion import messages_create

# from examples.pinecone_example.basic import basic
# from examples.chroma_example.basic import basic
# from examples.llamaindex_example.basic import basic
# from examples.langchain_example.basic import basic
# from examples.cohere_example.chat import chat_comp
# from examples.cohere_example.embed_create import embed_create
from examples.hiveagent_example.basic import basic

# from examples.cohere_example.chat_stream import chat_stream

# from examples.perplexity_example.basic import basic

# load_and_split()
# rag()
basic()
# chat_completion()
# function_calling()
# images_generate()
# embeddings_create()
# messages_create()
# chat_comp()
# embed_create()
# chat_stream()
